@@ -121,7 +121,7 @@ proc SymbolControl { name option value } {
     set variable $name$option
 
     set count 0
-    foreach i { Line Circle Cross Diamond Plus Square } {
+    foreach i { Line Circle Cross Diamond Plus Square Scross Splus } {
 	radiobutton $frame.rbutton_$i -variable $variable -value $i -text $i \
 	    -command "$setProc($name) $option \$\{$variable\}"
 	blt_table $frame $frame.rbutton_$i $count/3,$count%3 -anchor w
@@ -416,6 +416,84 @@ proc FontReset { name option value } {
     $setProc($name) $option $value
 }
 
+proc MapXAxisControl { name option value } {
+    global row column table setProc
+
+    label $table($name).label$option -text $option 
+    frame $table($name).frame$option 
+    set frame $table($name).frame$option 
+    set variable $name$option
+
+    radiobutton $frame.rbutton_x1 -text "x" -variable $variable \
+	-command "$setProc($name) $option \$\{$variable\}" \
+	-value "x" 
+    radiobutton $frame.rbutton_x2 -text "x2" -variable $variable \
+	-command "$setProc($name) $option \$\{$variable\}" \
+	-value "x2"
+    radiobutton $frame.rbutton_both -text "both" -variable $variable \
+	-command "$setProc($name) $option \$\{$variable\}" \
+	-value "both"
+    blt_table $frame \
+	$frame.rbutton_x1 0,0 -anchor w \
+	$frame.rbutton_x2 0,1 -anchor w \
+	$frame.rbutton_both 0,2 -anchor w
+
+    blt_table $table($name) \
+	$table($name).label$option $row,$column -anchor w \
+	$table($name).frame$option $row,$column+1 -cspan 2 -fill x
+
+    global $variable
+    set $variable $value
+    incr row 
+}
+
+proc MapXAxisReset { name option value } {
+    global setProc
+    set variable $name$option
+    global $variable
+    set $variable $value
+    $setProc($name) $option $value
+}
+
+proc MapYAxisControl { name option value } {
+    global row column table setProc
+
+    label $table($name).label$option -text $option 
+    frame $table($name).frame$option 
+    set frame $table($name).frame$option 
+    set variable $name$option
+
+    radiobutton $frame.rbutton_y1 -text "y" -variable $variable \
+	-command "$setProc($name) $option \$\{$variable\}" \
+	-value "y" 
+    radiobutton $frame.rbutton_y2 -text "y2" -variable $variable \
+	-command "$setProc($name) $option \$\{$variable\}" \
+	-value "y2"
+    radiobutton $frame.rbutton_both -text "both" -variable $variable \
+	-command "$setProc($name) $option \$\{$variable\}" \
+	-value "both"
+    blt_table $frame \
+	$frame.rbutton_y1 0,0 -anchor w \
+	$frame.rbutton_y2 0,1 -anchor w \
+	$frame.rbutton_both 0,2 -anchor w
+
+    blt_table $table($name) \
+	$table($name).label$option $row,$column -anchor w \
+	$table($name).frame$option $row,$column+1 -cspan 2 -fill x
+
+    global $variable
+    set $variable $value
+    incr row 
+}
+
+proc MapYAxisReset { name option value } {
+    global setProc
+    set variable $name$option
+    global $variable
+    set $variable $value
+    $setProc($name) $option $value
+}
+
 #
 #
 # Component configuration routines
@@ -459,8 +537,6 @@ proc ResetGraph {} {
     EntryReset graph -title $graphOptions(-title)
     IntReset graph -topmargin $graphOptions(-topmargin)
     IntReset graph -width $graphOptions(-width)
-    EntryReset graph -xtitle $graphOptions(-xtitle)
-    EntryReset graph -ytitle $graphOptions(-ytitle)
     send $interp $graph configure $graphDefaults
 }
 
@@ -505,9 +581,9 @@ proc ConfigureGeneral {} {
     RGBColorControl graph -foreground $graphOptions(-foreground)
     IntControl graph -height 150 800 $graphOptions(-height)
     IntControl graph -leftmargin 0 100 $graphOptions(-leftmargin)
-    RGBColorControl graph -plotbackground $graphOptions(-plotbackground)
     set row 2
     set column 5
+    RGBColorControl graph -plotbackground $graphOptions(-plotbackground)
     IntControl graph -plotborderwidth 0 10 $graphOptions(-plotborderwidth)
     ReliefControl graph -plotrelief $graphOptions(-plotrelief)
     ReliefControl graph -relief $graphOptions(-relief)
@@ -515,8 +591,6 @@ proc ConfigureGeneral {} {
     EntryControl graph -title $graphOptions(-title)
     IntControl graph -topmargin 0 100 $graphOptions(-topmargin)
     IntControl graph -width 150 800 $graphOptions(-width)
-    EntryControl graph -xtitle $graphOptions(-xtitle)
-    EntryControl graph -ytitle $graphOptions(-ytitle)
 
     button $table($name).button_done -text "done" \
 	-command "destroy .$name; set varGeneral 0"
@@ -545,12 +619,14 @@ proc ResetAxis { axis } {
     IntReset axis -linewidth $axisOptions(-linewidth)
     BooleanReset axis -logscale $axisOptions(-logscale)
     BooleanReset axis -loose $axisOptions(-loose)
+    BooleanReset axis -mapped $axisOptions(-mapped)
     EntryReset axis -max $axisOptions(-max)
     EntryReset axis -min $axisOptions(-min)
     FloatReset axis -rotate 1.0 $axisOptions(-rotate)
     BooleanReset axis -showticks $axisOptions(-showticks)
     FloatReset axis -stepsize 1.0 $axisOptions(-stepsize)
     IntReset axis -subticks $axisOptions(-subticks)
+    EntryReset axis -title $axisOptions(-title)
     send $interp $graph $axis configure $axisDefaults
 }
 
@@ -594,25 +670,42 @@ proc ConfigureAxis {} {
     frame $table($name).frame -relief groove -bd 2
     label $table($name).title -text "Axis Configuration Options"
     
-    radiobutton $table($name).axis_x -text "X" -variable axis \
+    frame $table($name).axis 
+    radiobutton $table($name).axis.x -text "x" -variable axis \
 	-value "xaxis" \
 	-command "SetAxisOptions xaxis" 
 
-    radiobutton $table($name).axis_y -text "Y" -variable axis \
+    radiobutton $table($name).axis.y -text "y" -variable axis \
 	-value "yaxis" \
 	-command "SetAxisOptions yaxis" 
 
+    radiobutton $table($name).axis.x2 -text "x2" -variable axis \
+	-value "x2axis" \
+	-command "SetAxisOptions x2axis" 
+
+    radiobutton $table($name).axis.y2 -text "y2" -variable axis \
+	-value "y2axis" \
+	-command "SetAxisOptions y2axis" 
+
+    pack append $table($name).axis \
+	$table($name).axis.x { left expand fill } \
+	$table($name).axis.y { left expand fill } \
+	$table($name).axis.x2 { left expand fill } \
+	$table($name).axis.y2 { left expand fill } 
+
     RGBColorControl axis -color $axisOptions(-color)
     EntryControl axis -font $axisOptions(-font)
     IntControl axis -linewidth 0 10 $axisOptions(-linewidth)
     BooleanControl axis -logscale $axisOptions(-logscale)
     BooleanControl axis -loose $axisOptions(-loose)
+    BooleanControl axis -mapped $axisOptions(-mapped)
     EntryControl axis -max $axisOptions(-max)
     EntryControl axis -min $axisOptions(-min)
     FloatControl axis -rotate 0 360 1.0 $axisOptions(-rotate)
     BooleanControl axis -showticks $axisOptions(-showticks)
     FloatControl axis -stepsize 0 100 1.0 $axisOptions(-stepsize)
     IntControl axis -subticks 0 10 $axisOptions(-subticks)
+    EntryControl axis -title $axisOptions(-title)
     
     button $table($name).button_done -text "done" \
 	-command "destroy .$name; set varAxis 0"
@@ -623,8 +716,7 @@ proc ConfigureAxis {} {
 	$table($name).frame 0,0 -cspan 14 -rspan $row -fill both \
 	-padx 4 -pady 4 \
 	$table($name).title 		1,0 -cspan 7 \
-	$table($name).axis_x		2,1 \
-	$table($name).axis_y		2,2 \
+	$table($name).axis		2,1 -fill x -cspan 3  \
 	$table($name).button_reset 	$row,2 -reqwidth .7i -anchor w \
 	$table($name).button_done 	$row,3 -reqwidth .7i -anchor e
     blt_table column $table($name) configure 1 -padx 5
@@ -643,7 +735,11 @@ proc ResetLegend {} {
     IntReset legend -borderwidth $legendOptions(-borderwidth)
     EntryReset legend -font $legendOptions(-font)
     RGBColorReset legend -foreground $legendOptions(-foreground)
+    IntReset legend -ipadx $legendOptions(-ipadx)
+    IntReset legend -ipady $legendOptions(-ipady)
     BooleanReset legend -mapped $legendOptions(-mapped)
+    IntReset legend -padx $legendOptions(-padx)
+    IntReset legend -pady $legendOptions(-pady)
     EntryReset legend -position $legendOptions(-position)
     ReliefReset legend -relief $legendOptions(-relief)
     send $interp $graph legend configure $legendDefaults
@@ -687,7 +783,11 @@ proc ConfigureLegend {} {
     IntControl legend -borderwidth 0 10 $legendOptions(-borderwidth)
     EntryControl legend -font $legendOptions(-font)
     RGBColorControl legend -foreground $legendOptions(-foreground)
+    IntControl legend -ipadx 0 10 $legendOptions(-ipadx)
+    IntControl legend -ipady 0 10 $legendOptions(-ipady)
     BooleanControl legend -mapped $legendOptions(-mapped)
+    IntControl legend -padx 0 10 $legendOptions(-padx)
+    IntControl legend -pady 0 10 $legendOptions(-pady)
     EntryControl legend -position $legendOptions(-position)
     ReliefControl legend -relief $legendOptions(-relief)
 
@@ -705,8 +805,9 @@ proc ConfigureLegend {} {
     blt_table column $table($name) configure 1 -padx 5
     blt_table row $table($name) configure all -pady 5
     blt_table column $table($name) configure { 0 4 } -width 0.25i
-    blt_table row $table($name) configure { 0 10 } -height 0.125i
-    blt_table row $table($name) configure { 11 } -height {}
+    blt_table column $table($name) configure { 0 4 } -width 0.25i
+    blt_table row $table($name) configure { 0 $row-1 } -height 0.125i
+    blt_table row $table($name) configure { $row } -height {}
 }
 
 proc ResetCrosshairs {} {
@@ -858,6 +959,8 @@ proc ResetElement {} {
     EntryReset element -data $elemOptions(-data)
     RGBColorReset element -foreground $elemOptions(-foreground)
     EntryReset element -label $elemOptions(-label)
+    MapXAxisReset element -mapx $elemOptions(-mapx)
+    MapYAxisReset element -mapy $elemOptions(-mapy)
     EntryReset element -xdata $elemOptions(-xdata)
     EntryReset element -ydata $elemOptions(-ydata)
 
@@ -947,6 +1050,8 @@ proc ConfigureElement {} {
 	RGBColorControl element -foreground $elemOptions(-foreground)
 	EntryControl element -label $elemOptions(-label)
 	IntControl element -linewidth 0 10 $elemOptions(-linewidth)
+	MapXAxisControl element -mapx $elemOptions(-mapx)
+	MapYAxisControl element -mapy $elemOptions(-mapy)
 	BooleanControl element -noretrace  $elemOptions(-noretrace)
 	SymbolControl element -symbol $elemOptions(-symbol)
 	FloatControl element -scale 0 300 0.01 $elemOptions(-scale)
@@ -958,6 +1063,8 @@ proc ConfigureElement {} {
 	EntryControl element -data $elemOptions(-data)
 	RGBColorControl element -foreground $elemOptions(-foreground)
 	EntryControl element -label $elemOptions(-label)
+	MapXAxisControl element -mapx $elemOptions(-mapx)
+	MapYAxisControl element -mapy $elemOptions(-mapy)
 	ReliefControl element -relief $elemOptions(-relief)
 	BooleanControl element -stacked $elemOptions(-stacked)
 	EntryControl element -stipple $elemOptions(-stipple)
