@@ -374,7 +374,8 @@ AsciiToSource(interp, elemList, width, height, dataPtrPtr)
     } else if (numValues == (arraySize / 2)) {
 	format = V10;
     } else {
-	Tcl_AppendResult(interp, "wrong # data values in bitmap", (char *)NULL);
+	Tcl_AppendResult(interp, "bitmap has wrong # of data values",
+	    (char *)NULL);
 	goto error;
     }
     padding = 0;
@@ -565,11 +566,6 @@ DefineBitmap(tkwin, interp, argc, argv)
 	    " define name data\"", (char *)NULL);
 	return TCL_ERROR;
     }
-    if (argc < 4) {
-	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
-	    " compose name text ?flags?\"", (char *)NULL);
-	return TCL_ERROR;
-    }
     /* Initialize info and process flags */
 
     dimArr = elemArr = NULL;
@@ -696,8 +692,7 @@ BitmapHeight(tkwin, interp, argc, argv)
 	return TCL_ERROR;
     }
     Tk_SizeOfBitmap(Tk_Display(tkwin), bitmap, &width, &height);
-    sprintf(string, "%d", height);
-    Tcl_AppendResult(interp, string, (char *)NULL);
+    sprintf(interp->result, "%d", height);
     Tk_FreeBitmap(Tk_Display(tkwin), bitmap);
     return TCL_OK;
 }
@@ -732,8 +727,7 @@ BitmapWidth(tkwin, interp, argc, argv)
 	return TCL_ERROR;
     }
     Tk_SizeOfBitmap(Tk_Display(tkwin), bitmap, &width, &height);
-    sprintf(string, "%d", width);
-    Tcl_AppendResult(interp, string, (char *)NULL);
+    sprintf(interp->result, "%d", width);
     Tk_FreeBitmap(Tk_Display(tkwin), bitmap);
     return TCL_OK;
 }
@@ -759,7 +753,7 @@ BitmapBits(tkwin, interp, argc, argv)
 
     if (argc != 3) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
-	    " width name\"", (char *)NULL);
+	    " bits name\"", (char *)NULL);
 	return TCL_ERROR;
     }
     bitmap = Tk_GetBitmap(interp, tkwin, Tk_GetUid(argv[2]));
@@ -794,7 +788,7 @@ BitmapData(tkwin, interp, argc, argv)
 
     if (argc != 3) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
-	    " width name\"", (char *)NULL);
+	    " data name\"", (char *)NULL);
 	return TCL_ERROR;
     }
     bitmap = Tk_GetBitmap(interp, tkwin, Tk_GetUid(argv[2]));
