@@ -1,4 +1,3 @@
-
 /*
  * bltGrAxis.c --
  *
@@ -51,9 +50,9 @@
 #define MAJOR_TICK 	0.020	/* Length of a major tick */
 #define MINOR_TICK 	0.015	/* Length of a minor (sub)tick */
 #define LABEL_TICK 	0.030	/* Distance from graph to start of label */
-#define NUMDIGITS	12 	/* Specifies the number of digits
-				 * accuracy used when outputing axis
-				 * tick labels. */
+#define NUMDIGITS	12	/* Specifies the number of digits of
+				* accuracy used when outputting axis
+				* tick labels. */
 
 enum LimitIndices {
     LMIN, LMAX
@@ -135,28 +134,31 @@ typedef struct {
 
     /* User-definable fields */
     char *title;		/* Axis title */
-    int showTicks;		/* If non-zero, display (both major and 
-				 * minor) ticks on the axis */
+    int showTicks;		/* If non-zero, display (both major
+				 * and minor) ticks on the axis */
     int loose;			/* If non-zero, autoscale limits loosely */
     Tk_Anchor anchor;		/* Anchor of tick labels */
     double limits[2];		/* Limits for scaling of axis */
     double prevMin, prevMax;	/* Last limits for scaling of axis */
-    double reqStep;		/* Manually selected step size for major
-				 * ticks: If zero or less, automatically
-				 * calculate a "best" step size based on 
-				 * range of values. */
-    int reqSubTicks;		/* Manually selected number of subticks: The
-				 * default value is 2. */
+    double reqStep;		/* Manually selected step size for
+				 * major ticks: If zero or less,
+				 * automatically calculate a "best"
+				 * step size based on range of
+				 * values. */
+    int reqSubTicks;		/* Manually selected # of subticks:
+				 * The default value is 2. */
     XFontStruct *fontPtr;	/* Font used to draw tick labels. */
-    XColor *fgColorPtr;		/* Foreground color for ticks, labels, and
-				 * axis */
+    XColor *fgColorPtr;		/* Foreground color for ticks, labels,
+				 * and axis */
     int lineWidth;		/* Line thickness of axis and ticks */
     double theta;		/* Rotation of tick labels in degrees. */
-    char *formatCmd;		/* If non-NULL, indicates a Tcl proc to call
-				 * when formatting tick labels. See the 
-				 * manual for its usage. */
+    char *formatCmd;		/* If non-NULL, indicates a Tcl proc
+				 * to call when formatting tick
+				 * labels. See the manual for its
+				 * usage. */
     double subStep;		/* Step interval between minor ticks */
-    int subTicks;		/* # of minor ticks between major ticks */
+    int subTicks;		/* # of minor ticks between major
+				 * ticks */
     double step;		/* Step interval between major ticks */
     int numTicks;		/* # of major ticks possible on axis:
 				 * Calculated by tick layout routines. */
@@ -172,34 +174,42 @@ typedef struct {
     enum AxisTypes type;	/* Type of axis */
     unsigned int width, height;	/* Bounding box of axis */
 
-    double tickMin, tickMax;	/* Smallest, largest possible tick on plot */
+    double tickMin, tickMax;	/* Smallest and largest possible major
+				 * ticks on the plot */
     double min, max;		/* Actual (including padding) axis limits */
     double range;		/* Range of values (max-min) */
-    double scale;		/* Scale factor to convert values to pixels */
+    double scale;		/* Scale factor to convert values to
+				 * pixels */
     int offset;			/* Offset of plotting region from window
 				 * origin */
 
-    XSegment *segArr;		/* Array of computed tick line segments. Also
-				 * includes the axis line */
+    XSegment *segArr;		/* Array of computed tick line
+				 * segments. Also includes the axis
+				 * line */
     int numSegments;		/* Size of the above segment array */
 
     Label *labelArr;		/* Array of computed tick labels: See the
 				 * description of the Label structure. */
     int numLabels;		/* Size of the above label array */
     GC lineGC;			/* Graph context for axis lines and ticks */
-    GC textGC;			/* Graphic context for tick labels: Must be
-				 * private (can't use Tk_GetGC) because the
-				 * FillStyle, TSOrigin, and Stipple fields may
+    GC textGC;			/* Graphic context for tick labels:
+				 * Must be a private GC (can't use
+				 * Tk_GetGC) because the FillStyle,
+				 * TSOrigin, and Stipple fields may
 				 * change when the graph is layout is
-				 * calculated, due to rotation of text. Also,
-				 * note that the background is reset when the
-				 * background color of the graph changes. */
+				 * calculated, to accommodate rotation
+				 * of text. Also, note that the
+				 * background color is also reset when
+				 * the background color of the graph
+				 * changes. */
 
 
 } Axis;
 
 /* Axis flags: */
-#define AXIS_CONFIG_USER_BIT	0x10
+/* bits 0-3 contain the axis type information */
+#define AXIS_CONFIG_DIRTY	(1<<8)
+#define AXIS_CONFIG_USER_BIT	(1<<9)
 #define AXIS_CONFIG_MIN_MASK	(AXIS_CONFIG_USER_BIT << LMIN)
 #define AXIS_CONFIG_MAX_MASK	(AXIS_CONFIG_USER_BIT << LMAX)
 #define AXIS_CONFIG_MIN_SET(a) 	((a)->flags & AXIS_CONFIG_MIN_MASK)
@@ -234,8 +244,8 @@ static Tk_ConfigSpec xAxisConfigSpecs[] =
     {TK_CONFIG_BOOLEAN, "-loose", "xLoose", "AxisLoose",
 	(char *)NULL, Tk_Offset(Axis, loose), ALL_MASK},
     {TK_CONFIG_BOOLEAN, "-mapped", "xMapped", "AxisMapped",
-	 DEF_AXIS_STD_MAPPED, Tk_Offset(Axis, mapped), 
-	 TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
+	DEF_AXIS_STD_MAPPED, Tk_Offset(Axis, mapped),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_CUSTOM, "-max", "xMax", "AxisMax",
 	(char *)NULL, 0, ALL_MASK | TK_CONFIG_NULL_OK, &MaxLimitOption},
     {TK_CONFIG_CUSTOM, "-min", "xMin", "AxisMin",
@@ -279,8 +289,8 @@ static Tk_ConfigSpec x2AxisConfigSpecs[] =
     {TK_CONFIG_BOOLEAN, "-loose", "x2Loose", "AxisLoose",
 	(char *)NULL, Tk_Offset(Axis, loose), ALL_MASK},
     {TK_CONFIG_BOOLEAN, "-mapped", "x2Mapped", "AxisMapped",
-	 DEF_AXIS_ALT_MAPPED, Tk_Offset(Axis, mapped), 
-	 TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
+	DEF_AXIS_ALT_MAPPED, Tk_Offset(Axis, mapped),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_CUSTOM, "-max", "x2Max", "AxisMax",
 	(char *)NULL, 0, ALL_MASK | TK_CONFIG_NULL_OK, &MaxLimitOption},
     {TK_CONFIG_CUSTOM, "-min", "x2Min", "AxisMin",
@@ -317,8 +327,8 @@ static Tk_ConfigSpec yAxisConfigSpecs[] =
     {TK_CONFIG_BOOLEAN, "-logscale", "yLogscale", "AxisLogscale",
 	(char *)NULL, Tk_Offset(Axis, logScale), ALL_MASK},
     {TK_CONFIG_BOOLEAN, "-mapped", "yMapped", "AxisMapped",
-	 DEF_AXIS_STD_MAPPED, Tk_Offset(Axis, mapped), 
-	 TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
+	DEF_AXIS_STD_MAPPED, Tk_Offset(Axis, mapped),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_CUSTOM, "-max", "yMax", "AxisMax",
 	(char *)NULL, 0, ALL_MASK | TK_CONFIG_NULL_OK, &MaxLimitOption},
     {TK_CONFIG_CUSTOM, "-min", "yMin", "AxisMin",
@@ -345,7 +355,7 @@ static Tk_ConfigSpec y2AxisConfigSpecs[] =
 	DEF_AXIS_FG_MONO, Tk_Offset(Axis, fgColorPtr),
 	TK_CONFIG_MONO_ONLY | ALL_MASK},
     {TK_CONFIG_STRING, "-command", "y2Command", "AxisCommand",
-	(char *)NULL, Tk_Offset(Axis, formatCmd), 
+	(char *)NULL, Tk_Offset(Axis, formatCmd),
 	ALL_MASK | TK_CONFIG_NULL_OK},
     {TK_CONFIG_FONT, "-font", "y2Font", "AxisFont",
 	DEF_AXIS_FONT, Tk_Offset(Axis, fontPtr), ALL_MASK},
@@ -356,8 +366,8 @@ static Tk_ConfigSpec y2AxisConfigSpecs[] =
     {TK_CONFIG_BOOLEAN, "-logscale", "y2Logscale", "AxisLogscale",
 	(char *)NULL, Tk_Offset(Axis, logScale), ALL_MASK},
     {TK_CONFIG_BOOLEAN, "-mapped", "y2Mapped", "AxisMapped",
-	 DEF_AXIS_ALT_MAPPED, Tk_Offset(Axis, mapped), 
-	 TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
+	DEF_AXIS_ALT_MAPPED, Tk_Offset(Axis, mapped),
+	TK_CONFIG_DONT_SET_DEFAULT | ALL_MASK},
     {TK_CONFIG_CUSTOM, "-max", "y2Max", "AxisMax",
 	(char *)NULL, 0, ALL_MASK | TK_CONFIG_NULL_OK, &MaxLimitOption},
     {TK_CONFIG_CUSTOM, "-min", "y2Min", "AxisMin",
@@ -378,7 +388,7 @@ static Tk_ConfigSpec y2AxisConfigSpecs[] =
 static Tk_ConfigSpec *axisConfigSpecs[4] =
 {
     xAxisConfigSpecs, yAxisConfigSpecs,	/* Normal x-axis and y-axis */
-    x2AxisConfigSpecs, y2AxisConfigSpecs /* Alternate x-axis and y-axis */
+    x2AxisConfigSpecs, y2AxisConfigSpecs	/* Alternate x-axis and y-axis */
 };
 
 #ifndef sun
@@ -463,8 +473,8 @@ PrintAxisLimit(clientData, tkwin, widgRec, offset, freeProcPtr)
     if (axisPtr->flags & mask) {
 	char string[TCL_DOUBLE_SPACE + 1];
 
-	Tcl_PrintDouble(axisPtr->interp, axisPtr->limits[whichLimit], 
-		string);
+	Tcl_PrintDouble(axisPtr->interp, axisPtr->limits[whichLimit],
+	    string);
 	result = strdup(string);
 	if (result == NULL) {
 	    return "";
@@ -509,9 +519,9 @@ CreateLabel(graphPtr, axisPtr, value)
     }
     if (axisPtr->formatCmd != NULL) {
 	Tcl_ResetResult(axisPtr->interp);
-	if (Tcl_VarEval(axisPtr->interp, axisPtr->formatCmd, " ", 
-			Tk_PathName(graphPtr->tkwin), " ", 
-			string, (char *)NULL) != TCL_OK) {
+	if (Tcl_VarEval(axisPtr->interp, axisPtr->formatCmd, " ",
+		Tk_PathName(graphPtr->tkwin), " ",
+		string, (char *)NULL) != TCL_OK) {
 	    Tk_BackgroundError(axisPtr->interp);
 	} else {
 	    result = axisPtr->interp->result;
@@ -742,7 +752,7 @@ Blt_PointOnGraph(graphPtr, pointPtr)
 
     /*
      * It doesn't make a difference which x-axis or y-axis we use
-     * since the point is referenced by window coordinates. 
+     * since the point is referenced by window coordinates.
      */
     axisPtr = (Axis *)graphPtr->axisArr[X1];
     if (axisPtr->scale == 0.0) {
@@ -774,7 +784,7 @@ Blt_PointOnGraph(graphPtr, pointPtr)
  *
  * ----------------------------------------------------------------------
  */
-static int
+static void
 UpdateLimits(axisPtr, listPtr)
     Axis *axisPtr;
     Blt_LinkedList *listPtr;
@@ -786,15 +796,16 @@ UpdateLimits(axisPtr, listPtr)
 	Blt_ListEntry *entryPtr;
 	register double min, max;
 	double elemMin, elemMax;
+	double value;
 
-	/* Find the minimum and maximum values for all the elements 
+	/* Find the minimum and maximum values for all the elements
 	   displayed */
 	min = Blt_posInfinity, max = Blt_negInfinity;
 	for (entryPtr = Blt_FirstListEntry(listPtr); entryPtr != NULL;
-	     entryPtr = Blt_NextListEntry(entryPtr)) {
+	    entryPtr = Blt_NextListEntry(entryPtr)) {
 	    elemPtr = (Element *)Blt_GetListValue(entryPtr);
 	    if ((*elemPtr->limitsProc) (elemPtr, (GraphAxis *)axisPtr,
-					&elemMin, &elemMax) > 0) {
+		    &elemMin, &elemMax) > 0) {
 		if (min > elemMin) {
 		    min = elemMin;
 		}
@@ -803,28 +814,36 @@ UpdateLimits(axisPtr, listPtr)
 		}
 	    }
 	}
-
 	/*
 	 * When auto-scaling, the axis limits are the bounds of the
 	 * element data.  If no data exists, set arbitrary limits (wrt
-	 * to log/linear scale). 
+	 * to log/linear scale).
 	 */
 	if (min == Blt_posInfinity) {
-	    min = (axisPtr->logScale) ? 1.0 : -10.0;
+	    min = (axisPtr->logScale) ? 0.001 : -10.0;
 	}
 	if (max == Blt_negInfinity) {
 	    max = 10.0;
 	}
+	/*
+	 * Handle situations where only one limit is set.
+	 */
+	value = min;
+	if (AXIS_CONFIG_MIN_SET(axisPtr)) {
+	    min = value = axisPtr->limits[LMIN];
+	} else if (AXIS_CONFIG_MAX_SET(axisPtr)) {
+	    max = value = axisPtr->limits[LMAX];
+	}
 	/* If there's no range of data (min >= max), manufacture one */
 	if (min >= max) {
-	    if (min == 0.0) {
+	    if (value == 0.0) {
 		min = -0.1, max = 0.1;
 	    } else {
 		double x;
-		
-		x = FABS(min) * 0.1;
-		min = min - x;
-		max = min + x;
+
+		x = FABS(value) * 0.1;
+		min = value - x;
+		max = value + x;
 	    }
 	}
 	if (!AXIS_CONFIG_MIN_SET(axisPtr)) {
@@ -833,7 +852,6 @@ UpdateLimits(axisPtr, listPtr)
 	if (!AXIS_CONFIG_MAX_SET(axisPtr)) {
 	    axisPtr->limits[LMAX] = max;
 	}
-
     }
     /* Indicate if the axis limits have changed */
     result = (axisPtr->limits[LMAX] != axisPtr->prevMax) ||
@@ -842,8 +860,8 @@ UpdateLimits(axisPtr, listPtr)
 	/* Save the previous minimum and maximum values */
 	axisPtr->prevMin = axisPtr->limits[LMIN];
 	axisPtr->prevMax = axisPtr->limits[LMAX];
+	axisPtr->flags |= AXIS_CONFIG_DIRTY;
     }
-    return (result);
 }
 
 /*
@@ -1117,8 +1135,8 @@ LinearAxis(axisPtr)
     }
 
     /*
-     * Find outer tick values in terms of the major step interval Add
-     * +0.0 to preclude the possibility of an IEEE -0.0. 
+     * Find the outer tick values in terms of the major step interval.
+     * Add +0.0 to preclude the possibility of an IEEE -0.0.
      */
 
     axisPtr->tickMin = UFLOOR(min, axisPtr->step) + 0.0;
@@ -1129,7 +1147,7 @@ LinearAxis(axisPtr)
     /*
      * If the axis is "loose", the range is between the two outermost
      * ticks. Otherwise if it's "tight", the range is between the data
-     * min and max. 
+     * min and max.
      */
     if (axisPtr->loose) {
 	axisPtr->min = axisPtr->tickMin, axisPtr->max = axisPtr->tickMax;
@@ -1141,7 +1159,7 @@ LinearAxis(axisPtr)
      * If is a limit is auto-scaled, add some padding so that the
      * symbols representing data points at the extremes aren't clipped
      * in half by the edge of the plot.  Two percent is an arbitrary
-     * guess. 
+     * guess.
      */
 
     pad = (axisPtr->max - axisPtr->min) * 0.02;
@@ -1198,14 +1216,18 @@ SetAxisLimits(graphPtr, axisPtr)
 	    axisPtr->limits[LMAX] = 0.0;
 	}
     }
-    if (UpdateLimits(axisPtr, &(graphPtr->elemList))) {
+    UpdateLimits(axisPtr, &(graphPtr->elemList));
+
+    if (axisPtr->flags & AXIS_CONFIG_DIRTY) {
 	/* Calculate min/max tick (major/minor) layouts */
 	if (axisPtr->logScale) {
 	    LogAxis(axisPtr);
 	} else {
 	    LinearAxis(axisPtr);
 	}
-	/* If a limit changes, we need to re-layout the entire graph. */
+	axisPtr->flags &= ~AXIS_CONFIG_DIRTY;
+
+	/* When any axis changes, we need to layout the entire graph. */
 	graphPtr->flags |= (LAYOUT_PENDING | LAYOUT_ALL | REDRAW_ALL);
     }
 }
@@ -1240,7 +1262,7 @@ Blt_ComputeAxes(graphPtr)
  * ConfigureAxis --
  *
  *	Configures axis attributes (font, line width, label, etc) and
- *	allocates a new (possibly shared) graphics context.  Line cap 
+ *	allocates a new (possibly shared) graphics context.  Line cap
  *	style is projecting.  This is for the problem of when a tick
  *	sits directly at the end point of the axis.
  *
@@ -1281,8 +1303,8 @@ ConfigureAxis(graphPtr, axisPtr, argc, argv, flags)
 	return TCL_ERROR;
     }
     /*
-     * Check requested X and Y axis limits. Can't allow min to be 
-     * greater than max, or undefined log scale limits.
+     * Check requested X and Y axis limits. Can't allow min to be
+     * greater than max, or have undefined log scale limits.
      */
     if ((AXIS_CONFIG_MIN_SET(axisPtr)) && (AXIS_CONFIG_MAX_SET(axisPtr)) &&
 	(axisPtr->limits[LMIN] >= axisPtr->limits[LMAX])) {
@@ -1300,10 +1322,10 @@ ConfigureAxis(graphPtr, axisPtr, argc, argv, flags)
 	    axisPtr->limits[LMAX]);
 	return TCL_ERROR;
     }
-    /* 
+    /*
      * Reset bogus line widths to zero. Can't allow bad line widths
      * because the layout routines compute axis and tick positions
-     * with them. 
+     * with them.
      */
     if (axisPtr->lineWidth < 1) {
 	axisPtr->lineWidth = 0;
@@ -1311,7 +1333,7 @@ ConfigureAxis(graphPtr, axisPtr, argc, argv, flags)
     /*
      * Create an unshared GC for the tick labels. The GC is private
      * because the labels may be rotated, requiring the GCStipple and
-     * GCTSOffset fields to change. 
+     * GCTSOffset fields to change.
      */
     gcMask = GCForeground | GCFont;
     gcValues.font = axisPtr->fontPtr->fid;
@@ -1320,8 +1342,8 @@ ConfigureAxis(graphPtr, axisPtr, argc, argv, flags)
 	gcValues.background = Tk_3DBorderColor(graphPtr->border)->pixel;
 	gcMask |= GCBackground;
     }
-    newGC = XCreateGC(graphPtr->display, Tk_WindowId(graphPtr->tkwin), 
-		      gcMask, &gcValues);
+    newGC = XCreateGC(graphPtr->display, Tk_WindowId(graphPtr->tkwin),
+	gcMask, &gcValues);
     if (axisPtr->textGC != NULL) {
 	XFreeGC(graphPtr->display, axisPtr->textGC);
     }
@@ -1338,8 +1360,8 @@ ConfigureAxis(graphPtr, axisPtr, argc, argv, flags)
     }
     axisPtr->lineGC = newGC;
 
+    axisPtr->flags |= AXIS_CONFIG_DIRTY;
     SetAxisLimits(graphPtr, axisPtr);
-    graphPtr->flags |= (REDRAW_ALL | LAYOUT_PENDING | LAYOUT_ALL);
     Blt_EventuallyRedraw(graphPtr);
     return TCL_OK;
 }
@@ -1420,7 +1442,7 @@ CalculateOffsets(graphPtr, axisPtr)
     titleOffset = graphPtr->extBWidth + textHeight;
 
     /*
-     * Pre-calculate the x-coordinate positions of the baseline, 
+     * Pre-calculate the x-coordinate positions of the baseline,
      * tick labels, and the individual major and minor ticks.
      */
     if (axisPtr->flags & AXIS_X_MASK) {
@@ -1589,7 +1611,6 @@ LayoutAxis(graphPtr, axis)
     if (!axisPtr->showTicks) {
 	goto done;		/* Only display axis line */
     }
-
     /* Use numbers just beyond the limits when testing for equality */
     min -= (axisPtr->subStep * 0.001);
     max += (axisPtr->subStep * 0.001);
@@ -1703,8 +1724,8 @@ DisplayAxis(graphPtr, axis, attrPtr)
 		axisPtr->labelArr[i].x, axisPtr->labelArr[i].y);
 	}
 	if (axisPtr->numSegments > 0) {
-	    XDrawSegments(graphPtr->display, graphPtr->canvas, 
- 		axisPtr->lineGC, axisPtr->segArr, axisPtr->numSegments);
+	    XDrawSegments(graphPtr->display, graphPtr->canvas,
+		axisPtr->lineGC, axisPtr->segArr, axisPtr->numSegments);
 	}
     }
 }
@@ -1877,11 +1898,11 @@ Blt_UpdateAxisBackgrounds(graphPtr, colorPtr)
  *           Area Width
  *      ___________________________________________________________
  *      |          |                               |               |
- *      |          |   TOP  height of title        |               | 
- *      |          |                               |               | 
- *      |          |           x2 title            |               | 
- *      |          |                               |               | 
- *      |          |        height of x2-axis      |               |  
+ *      |          |   TOP  height of title        |               |
+ *      |          |                               |               |
+ *      |          |           x2 title            |               |
+ *      |          |                               |               |
+ *      |          |        height of x2-axis      |               |
  *      |__________|_______________________________|_______________|  A
  *      |          |                        extreme|               |  r
  *      |          |                               |               |  e
@@ -1948,11 +1969,12 @@ Blt_ComputeLayout(graphPtr)
     y2 = (Axis *)graphPtr->axisArr[Y2];
 
     top = (graphPtr->title != NULL) ? twiceHeight : halfHeight;
-    left = ((y1->mapped) && (y1->title != NULL)) ? twiceHeight : 0;
+    left = ((y1->mapped) && (y1->title != NULL)) ? twiceHeight : halfHeight;
     bottom = ((x1->mapped) && (x1->title != NULL)) ? twiceHeight : halfHeight;
     right = ((y2->mapped) && (y2->title != NULL)) ? twiceHeight : 0;
-    top += ((x2->mapped) && (x2->title != NULL)) ? twiceHeight : halfHeight;
-
+    if ((x2->mapped) && (x2->title != NULL)) {
+	top += twiceHeight;
+    }
     GetAxisGeometry(graphPtr, x1);
     maxTickWidth = 0;
     normXScale = normYScale = 1.0 + LABEL_TICK;
@@ -1976,12 +1998,13 @@ Blt_ComputeLayout(graphPtr)
     (*graphPtr->legendPtr->geomProc) (graphPtr);
     if ((graphPtr->legendPtr->mapped) && (graphPtr->legendPtr->useDefault)) {
 	right += graphPtr->legendPtr->width;
+    } else {
+	right += halfHeight;
     }
     maxTickWidth = MAX(x1->width, x2->width) / 2;
     if (right < maxTickWidth) {
 	right = maxTickWidth;
     }
-
     /* Override calculated values if user specified margins */
 
     if (graphPtr->leftMargin > 0) {
@@ -2099,9 +2122,10 @@ InvTransformCoord(axisPtr, argc, argv)
     double value;
 
     if (argc != 4) {
-	Tcl_AppendResult(axisPtr->interp, "wrong # args: should be \"", argv[0],
-		" ", axisNames[axisPtr->type], "axis invtransform winPos\"",
-	    	(char *)NULL);
+	Tcl_AppendResult(axisPtr->interp, "wrong # args: should be \"",
+	    argv[0], " ", axisNames[axisPtr->type],
+	    "axis invtransform winPos\"",
+	    (char *)NULL);
 	return TCL_ERROR;
     }
     if (Tcl_GetInt(axisPtr->interp, argv[2], &coord) != TCL_OK) {
@@ -2256,8 +2280,8 @@ Blt_AxisCmd(graphPtr, axis, argc, argv, flags)
     } else if ((c == 't') && (strncmp(argv[2], "transform", length) == 0)) {
 	result = TransformCoord(axisPtr, argc, argv);
     } else {
-	Tcl_AppendResult(interp, "bad ", which, "axis option \"", argv[2], 
-		"\":  should be configure or limits", (char *)NULL);
+	Tcl_AppendResult(interp, "bad ", which, "axis option \"", argv[2],
+	    "\":  should be configure or limits", (char *)NULL);
 	return TCL_ERROR;
     }
     return result;
