@@ -29,6 +29,9 @@
 #include <X11/Xutil.h>
 
 extern int strcasecmp _ANSI_ARGS_((CONST char *s1, CONST char *s2));
+#ifndef sun
+extern char *strdup _ANSI_ARGS_((CONST char *s));
+#endif
 
 /* ----------------------------------------------------------------------
  * Custom option parse and print procedures
@@ -218,6 +221,7 @@ Blt_PrintAxisFlags(clientData, tkwin, widgRec, offset, freeProcPtr)
     int mask = (int)clientData;
 
     flags &= mask;
+    result = "";
     if ((flags == AXIS_X_MASK) || (flags == AXIS_Y_MASK)) {
 	result = "both";
     } else if (flags & AXIS_X1_FLAG) {
