@@ -1066,7 +1066,6 @@ PrintPreamble(graphPtr, fileName)
     PostScript *psPtr = (PostScript *)graphPtr->postscript;
     long date;
     char *version;
-    extern long time _ANSI_ARGS_((long *));
 
 #ifdef LOSE_INLINE_PROLOG
 #define STRING_LENGTH 400
@@ -1097,7 +1096,7 @@ PrintPreamble(graphPtr, fileName)
     sprintf(graphPtr->scratchPtr, "%%%%BoundingBox:  %d %d %d %d\n",
 	origin.x, 792 - (psPtr->height + origin.y),	/* Lower left */
 	origin.x + psPtr->width, (792 - origin.y));
-    date = time((long *)NULL);
+    date = time((time_t *) NULL);
     Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr,
 	"%%Creator: ", Tk_Class(graphPtr->tkwin),
 	" (Tk version ", version, ")\n",
