@@ -252,14 +252,14 @@ static Tk_ConfigSpec bitmapConfigSpecs[] =
 	TK_CONFIG_MONO_ONLY | TK_CONFIG_NULL_OK},
     {TK_CONFIG_SYNONYM, "-bg", "bmTagBackground", (char *)NULL, (char *)NULL,
 	0, 0},
+    {TK_CONFIG_BITMAP, "-bitmap", "bmTagBitmap", "TagBitmap",
+	(char *)NULL, Tk_Offset(BitmapTag, bitmap), TK_CONFIG_NULL_OK},
     {TK_CONFIG_CUSTOM, "-mapx", "bmTagMapX", "TagMapX",
 	DEF_TAG_AXIS, Tk_Offset(BitmapTag, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &XAxisFlagsOption},
     {TK_CONFIG_CUSTOM, "-mapy", "bmTagMapY", "TagMapY",
 	DEF_TAG_AXIS, Tk_Offset(BitmapTag, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &YAxisFlagsOption},
-    {TK_CONFIG_BITMAP, "-pattern", "bmTagPattern", "TagPattern",
-	(char *)NULL, Tk_Offset(BitmapTag, bitmap), TK_CONFIG_NULL_OK},
     {TK_CONFIG_SYNONYM, "-fg", "bmTagForeground", (char *)NULL, (char *)NULL,
 	0, 0},
     {TK_CONFIG_COLOR, "-foreground", "bmTagForeground", "TagForeground",
@@ -354,14 +354,14 @@ static Tk_ConfigSpec lineConfigSpecs[] =
 	TK_CONFIG_COLOR_ONLY},
     {TK_CONFIG_COLOR, "-foreground", "lineTagForeground", "TagForeground",
 	DEF_TAG_FG_MONO, Tk_Offset(LineTag, fgColorPtr), TK_CONFIG_MONO_ONLY},
+    {TK_CONFIG_PIXELS, "-linewidth", "lineTagLineWidth", "TagLineWidth",
+	(char *)NULL, Tk_Offset(LineTag, lineWidth), 0},
     {TK_CONFIG_CUSTOM, "-mapx", "lineTagMapX", "TagMapX",
 	DEF_TAG_AXIS, Tk_Offset(LineTag, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &XAxisFlagsOption},
     {TK_CONFIG_CUSTOM, "-mapy", "lineTagMapY", "TagMapY",
 	DEF_TAG_AXIS, Tk_Offset(LineTag, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &YAxisFlagsOption},
-    {TK_CONFIG_PIXELS, "-width", "lineTagLineWidth", "TagLineWidth",
-	(char *)NULL, Tk_Offset(LineTag, lineWidth), 0},
     {TK_CONFIG_PIXELS, "-xoffset", "lineTagXOffset", "TagXOffset",
 	(char *)NULL, Tk_Offset(LineTag, xOffset), 0},
     {TK_CONFIG_PIXELS, "-yoffset", "lineTagYOffset", "TagYOffset",
@@ -1335,7 +1335,7 @@ LayoutWindow(graphPtr, tagPtr)
 
 	anchorPos = Blt_TransformPt(graphPtr, winTagPtr->coordArr[0],
 	    winTagPtr->coordArr[1], winTagPtr->axisFlags);
-	anchorPos = Blt_TranslateBoxCoords(anchorPos.x, anchorPos.y, 
+	anchorPos = Blt_TranslateBoxCoords(anchorPos.x, anchorPos.y,
 	    winTagPtr->width, winTagPtr->height, winTagPtr->anchor);
 	winTagPtr->x = anchorPos.x + winTagPtr->xOffset;
 	winTagPtr->y = anchorPos.y + winTagPtr->yOffset;
@@ -2532,7 +2532,7 @@ Blt_TagCmd(graphPtr, argc, argv)
 	result = TagBefore(graphPtr, argc - 3, argv + 3);
     } else if ((c == 'c') && (length > 2) &&
 	(strncmp(argv[2], "coords", length) == 0)) {
-	if (argc < 3) {
+	if (argc < 4) {
 	    Tcl_AppendResult(graphPtr->interp, "wrong # args: should be \"",
 		argv[0], " tag coords tagId ?coords?\"", (char *)NULL);
 	}
