@@ -54,7 +54,7 @@
 #include <X11/Xatom.h>
 
 #ifndef GRAPH_VERSION
-#define GRAPH_VERSION "3.1"
+#define GRAPH_VERSION "3.2"
 #endif
 
 #define TRUE  1
@@ -64,7 +64,7 @@ static char *classNames[] =
 {
     "Blt_graph", "Blt_barchart"
 };
-static int configFlags[] =
+static unsigned int configFlags[] =
 {
     XYGRAPH_MASK, BARCHART_MASK
 };
@@ -337,8 +337,10 @@ WindowCoords(graphPtr, argc, argv)
     }
     /* Perform the transformation from window coordinates to data */
     winX = Blt_Transform(graphPtr->axisArr[X1], x);
+    sprintf(string, "%d", winX);
+    Tcl_AppendElement(graphPtr->interp, string);
     winY = Blt_Transform(graphPtr->axisArr[Y1], y);
-    sprintf(string, "%d %d", winX, winY);
+    sprintf(string, "%d", winY);
     Tcl_AppendElement(graphPtr->interp, string);
     return TCL_OK;
 }
@@ -374,7 +376,7 @@ DestroyGraph(clientData)
 
     /*
      * Destroy the individual components of the graph: elements, tags,
-     * X and Y axes, legend, display lists etc. 
+     * X and Y axes, legend, display lists etc.
      */
     for (entryPtr = Tcl_FirstHashEntry(&(graphPtr->elemTable), &cursor);
 	entryPtr != NULL; entryPtr = Tcl_NextHashEntry(&cursor)) {
@@ -437,9 +439,9 @@ CreateGraph(interp, parent, pathName, type)
     char *pathName;
     GraphClassType type;
 {
-    register Graph *graphPtr;
+    Graph *graphPtr;
     Tk_Window tkwin;
-    int flags = configFlags[(int)type];
+    unsigned int flags;
     register int i;
 
     tkwin = Tk_CreateWindowFromPath(interp, parent, pathName, (char *)NULL);
@@ -451,7 +453,7 @@ CreateGraph(interp, parent, pathName, type)
 	interp->result = "can't allocate graph structure";
 	return (Graph *) NULL;
     }
-    Tk_SetClass(tkwin, classNames[(int)type]);
+    Tk_SetClass(tkwin, classNames[type]);
 
     /* Initialize the data structure for the graph. */
 
@@ -469,10 +471,11 @@ CreateGraph(interp, parent, pathName, type)
     graphPtr->nextTagId = 1;
     /*
      * Axes and tags (text, bitmap) need private GCs, so create the
-     * window now. 
+     * window now.
      */
     Tk_MakeWindowExist(tkwin);
 
+    flags = configFlags[type];
     for (i = 0; i < 4; i++) {
 	if (Blt_CreateAxis(graphPtr, (AxisType)i, flags) != TCL_OK) {
 	    goto error;
@@ -487,7 +490,6 @@ CreateGraph(interp, parent, pathName, type)
     if (Blt_CreateLegend(graphPtr) != TCL_OK) {
 	goto error;
     }
-
     /* Compute the initial axis ticks and labels */
 
     Blt_ComputeAxes(graphPtr);
@@ -529,7 +531,7 @@ ConfigureGraph(graphPtr, argc, argv, flags)
     register Graph *graphPtr;	/* Graph widget record */
     int argc;			/* Number of configuration arguments */
     char **argv;		/* Configuration arguments */
-    int flags;			/* Configuration flags */
+    unsigned int flags;		/* Configuration flags */
 {
     XColor *borderColor;
     GC newGC;
@@ -558,7 +560,7 @@ ConfigureGraph(graphPtr, argc, argv, flags)
 
     /*
      * Create GCs for interior and exterior regions, and a background
-     * GC for clearing the margins with XFillRectangle 
+     * GC for clearing the margins with XFillRectangle
      */
     gcValues.foreground = graphPtr->fgColorPtr->pixel;
     gcValues.background = borderColor->pixel;
@@ -584,12 +586,12 @@ ConfigureGraph(graphPtr, argc, argv, flags)
     graphPtr->intGC = newGC;
     /*
      * Reconfigure the crosshairs in case the plotting area's
-     * background color changed 
+     * background color changed
      */
     (*graphPtr->crosshairs->configProc) (graphPtr);
 
     /* Title font, title strings, or margins may have changed layout */
-    graphPtr->flags |= REDRAW_ALL | LAYOUT_PENDING | LAYOUT_ALL;
+    graphPtr->flags |= (REDRAW_ALL | LAYOUT_PENDING | LAYOUT_ALL);
     Blt_EventuallyRedraw(graphPtr);
     return TCL_OK;
 }
@@ -620,6 +622,7 @@ GraphCmd(clientData, interp, argc, argv)
     Tk_Window tkwin = (Tk_Window)clientData;
     register Graph *graphPtr;
     GraphClassType type;
+    unsigned int flags;
 
     if (argc < 2) {
 	Tcl_AppendResult(interp, "wrong # args:  should be \"", argv[0],
@@ -643,8 +646,8 @@ GraphCmd(clientData, interp, argc, argv)
     if (graphPtr == NULL) {
 	return TCL_ERROR;
     }
-    if (ConfigureGraph(graphPtr, argc - 2,
-	    argv + 2, configFlags[(int)type]) != TCL_OK) {
+    flags = configFlags[type];
+    if (ConfigureGraph(graphPtr, argc - 2, argv + 2, flags) != TCL_OK) {
 	Tk_DestroyWindow(graphPtr->tkwin);
 	return TCL_ERROR;
     }
@@ -680,8 +683,8 @@ GraphWidgetCmd(clientData, interp, argc, argv)
     int result = TCL_ERROR;
     Tk_Window tkwin = graphPtr->tkwin;
     char c;
-    int length;
-    int flags;
+    unsigned int length;
+    unsigned int flags;
     GraphClassType type;
     GraphAxis *axisPtr;
 
@@ -695,7 +698,7 @@ GraphWidgetCmd(clientData, interp, argc, argv)
     c = argv[1][0];
     length = strlen(argv[1]);
     type = graphPtr->type;
-    flags = configFlags[(int)type] | TK_CONFIG_ARGV_ONLY;
+    flags = (configFlags[type] | TK_CONFIG_ARGV_ONLY);
 
     if ((c == 'c') && (length > 2) &&
 	(strncmp(argv[1], "configure", length) == 0)) {
@@ -796,7 +799,6 @@ Blt_LayoutGraph(graphPtr)
 	    (*axisPtr->layoutProc) (graphPtr, axisPtr);
 	}
     }
-
     /* Layout elements */
     for (entryPtr = Blt_FirstListEntry(&(graphPtr->elemList));
 	entryPtr != NULL; entryPtr = Blt_NextListEntry(entryPtr)) {
@@ -939,7 +941,7 @@ DisplayExterior(graphPtr, rectPtr)
 
     /*
      * Draw the four outer rectangles which encompass the plotting
-     * surface. This clears the surrounding area and clips the plot. 
+     * surface. This clears the surrounding area and clips the plot.
      */
 
     rectArr[0].x = rectArr[0].y = rectArr[3].x = rectArr[1].x = 0;
@@ -956,7 +958,8 @@ DisplayExterior(graphPtr, rectPtr)
 	rectArr, 4);
 
     /* Interior 3D border */
-    if ((graphPtr->intRelief != TK_RELIEF_FLAT) && (graphPtr->intBWidth > 0)) {
+    if ((graphPtr->intRelief != TK_RELIEF_FLAT) &&
+	(graphPtr->intBWidth > 0)) {
 	Tk_Draw3DRectangle(graphPtr->display, graphPtr->canvas,
 	    graphPtr->border, rectPtr->x, rectPtr->y, rectPtr->width,
 	    rectPtr->height, graphPtr->intBWidth, graphPtr->intRelief);
@@ -987,7 +990,8 @@ DisplayExterior(graphPtr, rectPtr)
 	}
     }
     /* Exterior 3D border */
-    if ((graphPtr->extRelief != TK_RELIEF_FLAT) && (graphPtr->extBWidth > 0)) {
+    if ((graphPtr->extRelief != TK_RELIEF_FLAT) &&
+	(graphPtr->extBWidth > 0)) {
 	Tk_Draw3DRectangle(graphPtr->display, graphPtr->canvas,
 	    graphPtr->border, 0, 0, graphPtr->width, graphPtr->height,
 	    graphPtr->extBWidth, graphPtr->extRelief);
@@ -1019,9 +1023,9 @@ DisplayGraph(clientData)
     int twiceBW;
     GraphLegend *legendPtr;
 
-    /* 
+    /*
      * If the window has been deleted or is no longer mapped, do
-     * nothing 
+     * nothing
      */
     graphPtr->flags &= ~REDRAW_PENDING;
     if ((graphPtr->tkwin == NULL) || (!Tk_IsMapped(graphPtr->tkwin))) {
@@ -1052,7 +1056,7 @@ DisplayGraph(clientData)
 
     /*
      * Create a canvas the size of the window, filling it with the
-     * plotting area's background color 
+     * plotting area's background color
      */
     graphPtr->canvas = XCreatePixmap(graphPtr->display,
 	Tk_WindowId(graphPtr->tkwin), graphPtr->width, graphPtr->height,
